@@ -24,35 +24,58 @@ EngineRestGitHub <- R6::R6Class(
       return(files_list)
     },
 
+    # Prepare files table from REST API.
+    prepare_files_table = function(files_list) {
+      files_table <- NULL
+      if (!is.null(files_list)) {
+        files_table <- purrr::map(files_list, function(file_data) {
+          repo_fullname <- private$get_repo_fullname(file_data$url)
+          org_repo <- stringr::str_split_1(repo_fullname, "/")
+          data.frame(
+            "repo_name" = org_repo[2],
+            "repo_id" = NA_character_,
+            "organization" = org_repo[1],
+            "file_path" = file_data$path,
+            "file_content" = file_data$content,
+            "file_size" = file_data$size,
+            "repo_url" = private$set_repo_url(file_data$url)
+          )
+        }) %>%
+          purrr::list_rbind()
+      }
+      return(files_table)
+    },
+
     # Pulling repositories where code appears
     get_repos_by_code = function(code,
-                                 org        = NULL,
-                                 filename   = NULL,
-                                 in_path    = FALSE,
-                                 output     = "table_full",
-                                 verbose    = TRUE,
-                                 progress   = TRUE) {
-      user_query <- if (!is.null(org)) {
-        paste0('+user:', org)
-      } else {
-        ''
-      }
-      query <- if (!in_path) {
-        paste0('"', code, '"', user_query)
-      } else {
-        paste0('"', code, '"+in:path', user_query)
-      }
-      if (!is.null(filename)) {
-        query <- paste0(query, '+in:file+filename:', filename)
-      }
-      search_endpoint <- paste0(private$endpoints[["search"]], query)
-      if (verbose) cli::cli_alert_info("Searching for code [{code}]...")
-      total_n <- self$response(search_endpoint)[["total_count"]]
-      if (length(total_n) > 0) {
-        search_result <- private$search_response(
-          search_endpoint = search_endpoint,
-          total_n = total_n
+                                 org = NULL,
+                                 repos = NULL,
+                                 filename = NULL,
+                                 in_path = FALSE,
+                                 output = "table_full",
+                                 verbose = TRUE,
+                                 progress = TRUE) {
+      if (!is.null(org)) {
+        search_result <- private$search_for_code(
+          code = code,
+          org = org,
+          filename = filename,
+          in_path = in_path,
+          verbose = verbose,
+          progress = progress
         )
+      }
+      if (!is.null(repos)) {
+        search_result <- private$search_repos_for_code(
+          code = code,
+          repos = repos,
+          filename = filename,
+          in_path = in_path,
+          verbose = verbose,
+          progress = progress
+        )
+      }
+      if (length(search_result) > 0) {
         if (output == "table_full" || output == "table_min") {
           search_output <- private$map_search_into_repos(
             search_response = search_result,
@@ -107,8 +130,14 @@ EngineRestGitHub <- R6::R6Class(
 
     #' Pull all repositories URLS from organization
     get_repos_urls = function(type, org, repos) {
-      repos_response <- self$response(
-        endpoint = paste0(private$endpoints[["organizations"]], org, "/repos")
+      owner_type <- attr(org, "type") %||% "organization"
+      if (owner_type == "user") {
+        repo_endpoint <- paste0(private$endpoints[["users"]], utils::URLdecode(org), "/repos")
+      } else {
+        repo_endpoint <- paste0(private$endpoints[["organizations"]], utils::URLdecode(org), "/repos")
+      }
+      repos_response <- private$paginate_results(
+        endpoint = repo_endpoint
       )
       if (!is.null(repos)) {
         repos_response <- repos_response %>%
@@ -166,11 +195,7 @@ EngineRestGitHub <- R6::R6Class(
           error = function(e) {
             NA
           })
-        }, .progress = if (progress) {
-          "[GitHost:GitHub] Pulling contributors..."
-        } else {
-          FALSE
-        })
+        }, .progress = progress)
       }
       return(repos_table)
     }
@@ -194,12 +219,82 @@ EngineRestGitHub <- R6::R6Class(
         self$rest_api_url,
         "/orgs/"
       )
+      private$endpoints[["users"]] <- paste0(
+        self$rest_api_url,
+        "/users/"
+      )
       private$endpoints[["repositories"]] <- paste0(
         self$rest_api_url,
         "/repos/"
       )
     },
 
+    search_for_code = function(code,
+                               org,
+                               filename,
+                               in_path,
+                               verbose,
+                               progress) {
+      user_query <- if (!is.null(org)) {
+        paste0('+user:', org)
+      } else {
+        ''
+      }
+      query <- if (!in_path) {
+        paste0('"', code, '"', user_query)
+      } else {
+        paste0('"', code, '"+in:path', user_query)
+      }
+      if (!is.null(filename)) {
+        query <- paste0(query, '+in:file+filename:', filename)
+      }
+      search_endpoint <- paste0(private$endpoints[["search"]], query)
+      if (verbose) cli::cli_alert_info("Searching for code [{code}]...")
+      total_n <- self$response(search_endpoint)[["total_count"]]
+      search_result <- if (length(total_n) > 0) {
+        private$search_response(
+          search_endpoint = search_endpoint,
+          total_n = total_n
+        )
+      } else {
+        list()
+      }
+      return(search_result)
+    },
+
+    search_repos_for_code = function(code,
+                                     repos,
+                                     filename,
+                                     in_path,
+                                     verbose,
+                                     progress) {
+      if (verbose) cli::cli_alert_info("Searching for code [{code}]...")
+      search_result <- purrr::map(repos, function(repo) {
+        repo_query <- paste0('+repo:', repo)
+        query <- if (!in_path) {
+          paste0('"', code, '"', repo_query)
+        } else {
+          paste0('"', code, '"+in:path', repo_query)
+        }
+        if (!is.null(filename)) {
+          query <- paste0(query, '+in:file+filename:', filename)
+        }
+        search_endpoint <- paste0(private$endpoints[["search"]], query)
+        total_n <- self$response(search_endpoint)[["total_count"]]
+        result <- if (length(total_n) > 0) {
+          private$search_response(
+            search_endpoint = search_endpoint,
+            total_n = total_n
+          )
+        } else {
+          list()
+        }
+        return(result)
+      }) |>
+        purrr::list_flatten()
+      return(search_result)
+    },
+
     # A wrapper for proper pagination of GitHub search REST API
     # @param search_endpoint A character, a search endpoint
     # @param total_n Number of results
@@ -302,6 +397,13 @@ EngineRestGitHub <- R6::R6Class(
       purrr::map(search_result, ~ self$response(.$url),
                  .progress = glue::glue("Adding file [{filename}] info...")) %>%
         unique()
+    },
+
+    # Get repository full name
+    get_repo_fullname = function(file_url) {
+      stringr::str_remove_all(file_url,
+                              paste0(private$endpoints$repositories, "/")) %>%
+        stringr::str_replace_all("/contents.*", "")
     }
   )
 )
